<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sc">
<context>
    <name>App.About</name>
    <message>
        <location filename="../main.cpp" line="92"/>
        <source>System Monitor</source>
        <translation>المراقبة النظامية</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>المراقبة النظامية أداة تُستخدم لمراقبة تحميل النظام في الوقت الحقيقي، وعرض وتحكم العمليات والخدمات التي تعمل على نظامك.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="28"/>
        <source>Hide details</source>
        <translation>إخفاء التفاصيل</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="39"/>
        <source>Overall utilization</source>
        <translation>الاستخدام الكلي</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="42"/>
        <source>Individual utilization</source>
        <translation>الاستخدام الفردي</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="138"/>
        <source>Read</source>
        <translation>القراءة</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="142"/>
        <source>Write</source>
        <translation>الكتابة</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <location filename="../gui/cpu_detail_widget.cpp" line="154"/>
        <source>60 seconds</source>
        <translation>60 ثانية</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <location filename="../model/cpu_info_model.cpp" line="43"/>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 أيام %2 ساعات %3 دقائق</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="91"/>
        <source>Utilization</source>
        <translation>الاستخدام</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="93"/>
        <source>Frequency</source>
        <translation>Average frequency</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="98"/>
        <source>Max frequency</source>
        <translation>التردد</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="100"/>
        <source>Average frequency</source>
        <translation>Average frequency</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="104"/>
        <source>Up time</source>
        <translation>وقت التشغيل</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="106"/>
        <source>Sockets</source>
        <translation>الsockets</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="110"/>
        <source>Logical processors</source>
        <translation>المحررات الافتراضية</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="112"/>
        <source>Virtualization</source>
        <translation>الاستنساخ</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="116"/>
        <source>L1i cache</source>
        <translation>الذاكرة العشوائية L1i</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="118"/>
        <source>L1d cache</source>
        <translation>الذاكرة العشوائية L1d</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="122"/>
        <source>L2 cache</source>
        <translation>الذاكرة العشوائية L2</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="124"/>
        <source>L3 cache</source>
        <translation>الذاكرة العشوائية L3</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="128"/>
        <source>Load average</source>
        <translation>معدل الحمل</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="130"/>
        <source>File descriptors</source>
        <translation>الوصف الملفي</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="134"/>
        <source>Processes</source>
        <translation>Processes</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="136"/>
        <source>Threads</source>
        <translation>الخيوط</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="140"/>
        <source>Host name</source>
        <translation>اسم المضيف</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="142"/>
        <source>OS type</source>
        <translation>نوع نظام التشغيل</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="146"/>
        <source>Version</source>
        <translation>النسخة</translation>
    </message>
</context>
<context>
    <name>Cancel</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="298"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <location filename="../gui/chart_view_widget.cpp" line="293"/>
        <source>60 seconds</source>
        <translation>60 ثانية</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="477"/>
        <source>No search results</source>
        <translation>لا توجد نتائج بحث</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="87"/>
        <source>Details</source>
        <translation>التفاصيل</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <location filename="../cpu_monitor.cpp" line="70"/>
        <source>Details</source>
        <translation>التفاصيل</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="165"/>
        <source>active</source>
        <translation>فعال</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="167"/>
        <source>reloading</source>
        <translation>يتم إعادة التحميل</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="169"/>
        <source>inactive</source>
        <translation>غير فعال</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="170"/>
        <source>failed</source>
        <translation>فشل</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="172"/>
        <source>activating</source>
        <translation>يتم التفعيل</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="174"/>
        <source>deactivating</source>
        <translation>يتم إيقافه</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="146"/>
        <source>stub</source>
        <translation>نموذج</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="149"/>
        <source>not-found</source>
        <translation>غير موجود</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="151"/>
        <source>bad-setting</source>
        <translation>إعداد خاطئ</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="152"/>
        <source>error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="153"/>
        <source>merged</source>
        <translation>دمج</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="154"/>
        <source>masked</source>
        <translation>مُستкро</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="147"/>
        <source>loaded</source>
        <translation>تم التحميل</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="297"/>
        <source>N/A</source>
        <translation>غير متوفر</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="295"/>
        <source>Auto</source>
        <translation>تلقائي</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="296"/>
        <source>Manual</source>
        <translation>يدوي</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="274"/>
        <source>enabled</source>
        <translation>مُفعّل</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="275"/>
        <source>disabled</source>
        <translation>غير مُفعّل</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="276"/>
        <source>static</source>
        <translation>ثابت</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="277"/>
        <source>transient</source>
        <translation>مؤقت</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="278"/>
        <source>indirect</source>
        <translation>غير مباشر</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="280"/>
        <source>enabled-runtime</source>
        <translation>مُفعّل في الوقت الحالي</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="281"/>
        <source>masked</source>
        <translation>مُستкро</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="283"/>
        <source>generated</source>
        <translation>تم إنشاؤه</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="217"/>
        <source>dead</source>
        <translation>متوقف</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="219"/>
        <source>start-pre</source>
        <translation>قبل البدء</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="221"/>
        <source>start</source>
        <translation>بدء</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="223"/>
        <source>start-post</source>
        <translation>بعد البدء</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="225"/>
        <source>running</source>
        <translation>يعمل</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="227"/>
        <source>exited</source>
        <translation>خرج</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="229"/>
        <source>reload</source>
        <translation>إعادة التحميل</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="231"/>
        <source>stop</source>
        <translation>الإيقاف</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="233"/>
        <source>stop-watchdog</source>
        <translation>إيقاف المراقب</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="235"/>
        <source>stop-sigterm</source>
        <translation>إيقاف بواسطة إشارة SIGTERM</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="237"/>
        <source>stop-sigkill</source>
        <translation>إيقاف بواسطة إشارة SIGKILL</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="239"/>
        <source>stop-post</source>
        <translation>إيقاف بعد</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="241"/>
        <source>final-sigterm</source>
        <translation>إيقاف نهائي بواسطة إشارة SIGTERM</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="243"/>
        <source>final-sigkill</source>
        <translation>إيقاف نهائي بواسطة إشارة SIGKILL</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="245"/>
        <source>failed</source>
        <translation>فشل</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="247"/>
        <source>auto-restart</source>
        <translation>إعادة التشغيل التلقائية</translation>
    </message>
</context>
<context>
    <name>DBusAlarmNotify</name>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="38"/>
        <source>Warning</source>
        <translation>تحذير</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="39"/>
        <source>Your CPU usage is higher than %1%!</source>
        <translation>استخدام المعالج الخاص بك يتجاوز %1%!</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="51"/>
        <source>Your memory usage is higher than %1%!</source>
        <translation>استخدام الذاكرة الخاصة بك يتجاوز %1%!</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="71"/>
        <source>View</source>
        <translation type="unfinished">View</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="62"/>
        <source>Used</source>
        <translation>المستعمل</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="64"/>
        <source>Available</source>
        <translation>المتوفر</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="68"/>
        <source>Shared</source>
        <translation>المشارك</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="70"/>
        <source>Cached</source>
        <translation>المخزن المؤقت</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="74"/>
        <source>Buffers</source>
        <translation>الuffers</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="76"/>
        <source>Cached swap</source>
        <translation>التبديل المخزن المؤقت</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="80"/>
        <source>Active</source>
        <translation type="unfinished">Active</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="82"/>
        <source>Inactive</source>
        <translation>غير النشط</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="86"/>
        <source>Dirty</source>
        <translation>الغير نظيف</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="88"/>
        <source>Mapped</source>
        <translation>المapped</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="92"/>
        <source>Total swap</source>
        <translation>التبديل الكلي</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="94"/>
        <source>Free swap</source>
        <translation>التبديل الحرة</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="98"/>
        <source>Slab</source>
        <translation>الSlab</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="64"/>
        <source>Model</source>
        <translation>النموذج</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="66"/>
        <source>Read speed</source>
        <translation>سرعة القراءة</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="70"/>
        <source>Write speed</source>
        <translation>سرعة الكتابة</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="72"/>
        <source>Capacity</source>
        <translation>السعة</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="76"/>
        <source>Sectors read</source>
        <translation>القطاعات المقرئة</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="78"/>
        <source>Reads/s</source>
        <translation>قراءات/ثانية</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="82"/>
        <source>Sectors read/s</source>
        <translation>قطاعات القراءة/ثانية</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="84"/>
        <source>Reads merged/s</source>
        <translation>قراءات مدمجة/ثانية</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="88"/>
        <source>Sectors written</source>
        <translation>قطاعات مكتوبة</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="90"/>
        <source>Writes completed </source>
        <translation>كتابة مكتملة</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="94"/>
        <source>Writes merged</source>
        <translation>كتابة مدمجة</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="96"/>
        <source>Writes/s</source>
        <translation>كتابة/ثانية</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="100"/>
        <source>Sectors written/s</source>
        <translation>قطاعات مكتوبة/ثانية</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="102"/>
        <source>Writes merged/s</source>
        <translation>كتابة مدمجة/ثانية</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <location filename="../gui/dialog/error_dialog.cpp" line="68"/>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="28"/>
        <source>System</source>
        <translation>نظام</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="34"/>
        <source>Display shortcuts</source>
        <translation>عرض الأختصارات</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="166"/>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>إنهاء هذا البرنامج قد يؤدي إلى فقدان البيانات.
هل أنت متأكد من أنك تريد الاستمرار؟</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="510"/>
        <source>End process</source>
        <translation>إنهاء البرنامج</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="367"/>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>إنهاء هذا البرنامج بالقوة قد يؤدي إلى فقدان البيانات.
هل أنت متأكد من أنك تريد الاستمرар؟</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="511"/>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>إنهاء هذا التطبيق بالقوة قد يؤدي إلى فقدان البيانات.
هل أنت متأكد من أنك تريد الاستمرار؟</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="519"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="520"/>
        <source>Force End</source>
        <comment>button</comment>
        <translation type="unfinished">Force End</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="173"/>
        <source>End</source>
        <comment>button</comment>
        <translation type="unfinished">End</translation>
    </message>
</context>
<context>
    <name>Logout</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="299"/>
        <source>Logout</source>
        <translation>الخروج</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../gui/main_window.cpp" line="172"/>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <location filename="../gui/mem_stat_view_widget.cpp" line="47"/>
        <source>Size</source>
        <translation>الحجم</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>IP address:</source>
        <translation>عنوان IP:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Netmask:</source>
        <translation>شبكة الواجهة:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Broadcast:</source>
        <translation>البث:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Prefixlen:</source>
        <translation>طول المقدمة:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Scope:</source>
        <translation>النطاق:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="293"/>
        <source>Connection type</source>
        <translation>نوع الاتصال</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="301"/>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="307"/>
        <source>Link quality</source>
        <translation>جودة الربط</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="312"/>
        <source>Signal strength</source>
        <translation>قوة الإشارة</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="317"/>
        <source>Noise level</source>
        <translation>مستوى الضوضاء</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="323"/>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="328"/>
        <source>Bandwidth</source>
        <translation>العرض النطاق</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="333"/>
        <source>RX packets</source>
        <translation>حزم RX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="338"/>
        <source>RX bytes</source>
        <translation>بايت RX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="343"/>
        <source>RX errors</source>
        <translation>أخطاء RX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="348"/>
        <source>RX dropped</source>
        <translation>حزم RX تم إسقاطها</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="353"/>
        <source>RX overruns</source>
        <translation>تجاوزات RX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="358"/>
        <source>RX frame</source>
        <translation>إطار RX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="363"/>
        <source>TX packets</source>
        <translation>حزم TX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="368"/>
        <source>TX bytes</source>
        <translation>بايت TX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="373"/>
        <source>TX errors</source>
        <translation>أخطاء TX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="383"/>
        <source>TX overruns</source>
        <translation>تجاوزات TX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="388"/>
        <source>TX carrier</source>
        <translation>الصافي TX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="267"/>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="282"/>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="378"/>
        <source>TX dropped</source>
        <translation>حزم TX تم إسقاطها</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="140"/>
        <source>Command line</source>
        <translation>السطر الأوامر</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="145"/>
        <source>Start time</source>
        <translation>وقت البدء</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="135"/>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <location filename="../gui/xwin_kill_preview_background_widget.cpp" line="146"/>
        <source>Click the application you want to end</source>
        <translation>اضغط على التطبيق الذي تريد إنهاؤه</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="144"/>
        <source>Memory</source>
        <translation>الذاكرة</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="89"/>
        <source>Receive</source>
        <translation>الاستقبال</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="220"/>
        <source>CPU</source>
        <translation>الوحدة العَملية</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="145"/>
        <source>Disk read</source>
        <translation>القراءة من القرص</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="146"/>
        <source>Disk write</source>
        <translation>الكتابة على القرص</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="176"/>
        <source>Memory</source>
        <translation>الذاكرة</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="187"/>
        <source>Swap</source>
        <translation>التبديل</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="188"/>
        <source>Not enabled</source>
        <translation>غير مفعل</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="152"/>
        <source>Download</source>
        <translation>التنزيل</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="157"/>
        <source>Upload</source>
        <translation>الرفع</translation>
    </message>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="145"/>
        <source>Network</source>
        <translation>الشبكة</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="154"/>
        <source>Total Received</source>
        <translation>الإجمالي المستلم</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="159"/>
        <source>Total Sent</source>
        <translation>الإجمالي المرسل</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="98"/>
        <source>Send</source>
        <translation>إرسال</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_detail_view_widget.cpp" line="17"/>
        <source>Disks</source>
        <translation>الأقراص</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="67"/>
        <source>Loading</source>
        <translation>التحميل</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="615"/>
        <source>Very high</source>
        <translation>عالٍ جدًا</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="623"/>
        <source>High</source>
        <translation>عالٍ</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="631"/>
        <source>Normal</source>
        <translation>عادي</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="639"/>
        <source>Low</source>
        <translation>منخفض</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="647"/>
        <source>Very low</source>
        <translation>منخفض جدًا</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="655"/>
        <source>Custom</source>
        <translation>مخصص</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="60"/>
        <source>Invalid</source>
        <translation>غير صحيح</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="179"/>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1، الخطأ: [%2] %3</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="138"/>
        <source>Failed to change process priority</source>
        <translation>فشل في تغيير أولوية العملية</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="61"/>
        <source>Applications</source>
        <translation>التطبيقات</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="63"/>
        <source>My processes</source>
        <translation>عملياتي</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="65"/>
        <source>All processes</source>
        <translation>جميع العمليات</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="246"/>
        <source>Failed to pause process</source>
        <translation>فشل في توقف العملية</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="249"/>
        <source>Failed to resume process</source>
        <translation>فشل في استئناف العملية</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="252"/>
        <source>Failed to kill process</source>
        <translation>فشل في إنهاء العملية</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="255"/>
        <source>Unknown error</source>
        <translation>خطأ غير معروف</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="311"/>
        <source>Failed in sending signal to process</source>
        <translation>فشل في إرسال إشارة إلى العملية</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="243"/>
        <source>Failed to end process</source>
        <translation>فشل في إنهاء العملية</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="58"/>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 تطبيقات و%2 عمليات تعمل)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="240"/>
        <source>No response</source>
        <translation>لا رد</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="245"/>
        <source>Suspend</source>
        <translation>إيقاف مؤقت</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="82"/>
        <source>Tray</source>
        <translation>اللوحة</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="662"/>
        <source>View command location</source>
        <translation>عرض موقع الأمر</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="79"/>
        <source>Properties</source>
        <translation>الخصائص</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="62"/>
        <source>End process</source>
        <translation>إنهاء العملية</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="74"/>
        <source>Resume process</source>
        <translation>استئناف العملية</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="85"/>
        <source>Kill process</source>
        <translation>الإيقاف</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="609"/>
        <source>Change priority</source>
        <translation>تغيير الأولوية</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="68"/>
        <source>Suspend process</source>
        <translation>الإيقاف المؤقت</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1024"/>
        <source>Custom Priority</source>
        <translation>الأولوية المخصصة</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1056"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1058"/>
        <source>Change</source>
        <comment>button</comment>
        <translation type="unfinished">Change</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="16"/>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="18"/>
        <source>CPU</source>
        <translation>المعالج</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="22"/>
        <source>Memory</source>
        <translation>الذاكرة</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="32"/>
        <source>Disk write</source>
        <translation>الكتابة في القرص</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="30"/>
        <source>Disk read</source>
        <translation>القراءة من القرص</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="28"/>
        <source>Download</source>
        <translation>التنزيل</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="26"/>
        <source>Upload</source>
        <translation>الرفع</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="34"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="20"/>
        <source>User</source>
        <translation>المستخدم</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="36"/>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Priority</source>
        <translation>الأولوية</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="23"/>
        <source>Shared memory</source>
        <translation>الذاكرة المشتركة</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="24"/>
        <source>Virtual memory</source>
        <translation>الذاكرة الافتراضية</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="366"/>
        <source>Not support</source>
        <translation>غير مدعوم</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="10"/>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="11"/>
        <source>System Protection</source>
        <translation>حماية النظام</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="12"/>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>عرض التحذيرات عندما تتجاوز الاستخدام العتبات</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="13"/>
        <source>CPU warning threshold (%)</source>
        <translation>نسبة تحذير المعالج (%)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="14"/>
        <source>Memory warning threshold (%)</source>
        <translation>نسبة تحذير الذاكرة (%)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="15"/>
        <source>Warning interval (min)</source>
        <translation>فترة التحذير (بالدقائق)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="16"/>
        <source>Notifications</source>
        <translation>الإشعارات</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <location filename="../service/service_manager.cpp" line="322"/>
        <source>Failed to set service startup type</source>
        <translation>فشل في تعديل نوع بدء تشغيل الخدمة</translation>
    </message>
    <message>
        <location filename="../service/service_manager.cpp" line="388"/>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>خطأ: فشل في تعديل نوع بدء تشغيل الخدمة بسبب فشل العملية الفرعية</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="150"/>
        <source>Service instance name</source>
        <translation>اسم مثيل الخدمة</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="34"/>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="35"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="114"/>
        <source>Refresh</source>
        <translation>تحديث</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="99"/>
        <source>Start</source>
        <translation>البدء</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="104"/>
        <source>Stop</source>
        <translation>停用</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="109"/>
        <source>Restart</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="537"/>
        <source>Auto</source>
        <translation>자동</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="538"/>
        <source>Manual</source>
        <translation>수동</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="536"/>
        <source>Startup type</source>
        <translation>시작 유형</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <location filename="../model/system_service_table_model.h" line="16"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="18"/>
        <source>Load</source>
        <translation>로드</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="23"/>
        <source>Sub</source>
        <translation>서브</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="30"/>
        <source>Description</source>
        <translation>설명</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="32"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="27"/>
        <source>Startup Type</source>
        <translation>시작 유형</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="21"/>
        <source>Start State</source>
        <translation>시작 상태</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="25"/>
        <source>Start Tactic</source>
        <translation>시작 전략</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="124"/>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="156"/>
        <source>(Modifiable)</source>
        <translation>(수정 가능)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="263"/>
        <source>Range: %1-%2</source>
        <translation>범위: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="55"/>
        <source>Force end application</source>
        <translation>응용 프로그램 강제 종료</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="140"/>
        <source>Expand</source>
        <translation>확장</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="143"/>
        <source>Compact</source>
        <translation>수축</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="135"/>
        <source>View</source>
        <translation>보기</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="40"/>
        <source>Search</source>
        <translation>검색</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="49"/>
        <source>Processes</source>
        <translation>프로세스</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="94"/>
        <source>Services</source>
        <translation>서비스</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="234"/>
        <source>Users</source>
        <translation>사용자</translation>
    </message>
</context>
<context>
    <name>User.Account.Operation</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="97"/>
        <source>Edit account information</source>
        <translation>계정 정보 편집</translation>
    </message>
</context>
<context>
    <name>User.Account.Type</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="145"/>
        <source>Administrator</source>
        <translation>관리자</translation>
    </message>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="145"/>
        <source>Standard User</source>
        <translation>표준 사용자</translation>
    </message>
</context>
</TS>
